package com.netease.nis.quicklogin_flutter_plugin

import android.content.Context
import android.util.Log
import com.netease.nis.quicklogin.QuickLogin
import com.netease.nis.quicklogin.listener.QuickLoginPreMobileListener
import com.netease.nis.quicklogin.listener.QuickLoginTokenListener
import io.flutter.plugin.common.EventChannel
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel.Result
import kotlinx.coroutines.CoroutineScope
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.MainScope
import kotlinx.coroutines.launch


/**
 * Created by hzhuqi on 2020/11/2
 */
class QuickLoginHelper : CoroutineScope by MainScope() {
    val TAG = "QuickLogin"
    private var quickLogin: QuickLogin? = null
    private var context: Context? = null
    var events: EventChannel.EventSink? = null

    fun init(context: Context, businessId: String, timeout: Int?, result: Result) {
        this.context = context
        quickLogin = QuickLogin.getInstance(context, businessId)
        quickLogin?.setDebugMode(true)
        timeout?.let {
            quickLogin?.setPrefetchNumberTimeout(it * 1000)//秒转化为毫秒
        }
        val map = HashMap<String, Any?>()
        map["success"] = true
        result.success(map)
    }

    fun setUiConfig(call: MethodCall) {
        val uiConfig = call.argument<Map<String, Any>>("uiConfig")
        quickLogin?.setUnifyUiConfig(UiConfigParser.getUiConfig(context!!, uiConfig!!, events))
    }

    /**
     * 预取号接口
     */
    fun preFetchNumber(result: Result) {
        val map = HashMap<String, Any?>()
        quickLogin?.prefetchMobileNumber(object : QuickLoginPreMobileListener() {
            override fun onGetMobileNumberSuccess(ydToken: String?, mobileNumber: String?) {
                map["success"] = true
                map["token"] = ydToken
                result.success(map)
            }

            override fun onGetMobileNumberError(ydToken: String?, msg: String?) {
                map["success"] = false
                map["token"] = ydToken
                map["errorMsg"] = msg
                result.success(map)
            }

        })
    }

    /**
     * 一键登录接口
     */
    fun onePassLogin(result: Result) {
        val map = HashMap<String, Any?>()
        quickLogin?.onePass(object : QuickLoginTokenListener() {
            override fun onGetTokenSuccess(ydToken: String?, accessCode: String?) {
                Log.d(QuickLogin.TAG, String.format("yd token is:%s accessCode is:%s", ydToken, accessCode))
                map["success"] = true
                map["ydToken"] = ydToken
                map["accessToken"] = accessCode
                result.success(map)
            }

            override fun onGetTokenError(ydToken: String?, msg: String?) {
                Log.e(QuickLogin.TAG, "获取运营商token失败:$msg")
                map["success"] = false
                map["ydToken"] = ydToken
                map["msg"] = msg
                result.success(map)
            }

            override fun onCancelGetToken() {
                Log.d(TAG, "用户取消登录")
                map["type"] = "login"
                map["success"] = false
                map["cancel"] = true
                launch(Dispatchers.Main) {
                    events?.success(map)
                }
            }
        })
    }

    fun quitActivity(result: Result) {
        quickLogin?.quitActivity()
    }

    fun checkVerifyEnable(result: Result) {
        val type = quickLogin?.checkNetWork(context, null)
        //5是未知类型
        if (type != 5 && type != 4) {
            val map = HashMap<String, Any?>()
            map["success"] = true
            result.success(map)
        } else {
            val map = HashMap<String, Any?>()
            map["success"] = false
            result.success(map)
        }
    }
}